GroupWithMetadata

Struct GroupWithMetadata 

pub struct GroupWithMetadata<G, I = G, P = G, L = I> {
    pub delimiter: Delimiter,
    pub contents: TokenWithMetadataVec<G, I, P, L>,
    pub span: Span,
    pub metadata: G,
}
A version of Group with arbitrary attached metadata. The tokens within this GroupWithMetadata also have metadata.

The fields of this struct are public, unlike Group’s. There are no getter/setter methods: use the fields directly.

See proc_macro2’s documentation for more information on Group.

Fields

delimiter: Delimitercontents: TokenWithMetadataVec<G, I, P, L>

A vector holding the tokens within this group, each with their own metadata.

span: Span

See Group::span. This span covers the entire group, including the delimiters.

metadata: G

The associated metadata.

Implementations

Source

impl<G, I, P, L> GroupWithMetadata<G, I, P, L>

pub fn strip_metadata(self) -> Group

Strips the metadata from this GroupWithMetadata, returning an ordinary Group.

The tokens within the group will also be stripped of their metadata.

pub fn delimiter(&self) -> Delimiter

👎Deprecated:

Use the delimiter field directly.

pub fn span(&self) -> Span

👎Deprecated:

Use the span field directly.

pub fn span_open(&self) -> Span

pub fn span_close(&self) -> Span

pub fn delim_span(&self) -> DelimSpan

pub fn set_span(&mut self, span: Span)

👎Deprecated:

Use the span field directly.