pub struct TokenWithMetadata<T, U> {
pub token: T,
pub metadata: U,
}Expand description
A simple struct holding a token and its associated metadata.
Though TokenWithMetadata::token is generic, it should be a token from
proc_macro2 other than Group (Ident, Punct, or Literal).
To get the token without metadata, simply read the
TokenWithMetadata::token field.
Fields
token: TThe token.
metadata: UThe associated metadata.