TokenWithMetadataVec

Type Alias TokenWithMetadataVec 

pub type TokenWithMetadataVec<G, I = G, P = G, L = I> = Vec<TokenTreeWithMetadata<G, I, P, L>>;
A type alias for a Vec of TokenTreeWithMetadatas.

Since TokenTreeWithMetadatas are not obtained from a TokenStream directly, and are built manually or derived from obtained TokenTrees, it doesn’t make much sense to use a restrictive “token with metadata stream” type. Instead, use vectors of tokens with metadata.

Aliased Type

pub struct TokenWithMetadataVec<G, I = G, P = G, L = I> { /* private fields */ }